package FL;

import java.io.*;
import java.util.*;
import static FL.Scanner.TokenType.*;

public class Scanner {

	public enum TokenType {
		OROUND, PLUS, CROUND, TIMES, TRUE, FALSE, OR, AND, EQUAL,
		IF, THEN, ELSE, ENDIF, LET, IN, ENDLET,
		SEMICOLON, COLON, COMMA, INT, BOOL, NUM, ID, EOF, UNKNOWN
	};

	protected static final Hashtable<String, TokenType>
		keywords = new Hashtable<String, TokenType>();
	static {
		for(TokenType tt : new TokenType [] {TRUE, FALSE,
					OR, AND, IF, THEN, ELSE, ENDIF,
					 LET, IN, ENDLET, INT, BOOL})
			keywords.put(tt.name().toLowerCase(), tt);
	}

	private final StreamTokenizer streamTokenizer;

	public TokenType ttype;
	public int nval;
	public String sval; 

	public Scanner(Reader reader) {
		streamTokenizer = new StreamTokenizer(reader);
		streamTokenizer.resetSyntax();
		streamTokenizer.parseNumbers();
		streamTokenizer.whitespaceChars('\u0000','\u0020');  
		streamTokenizer.wordChars('a','z');
		streamTokenizer.wordChars('A','Z');
		streamTokenizer.wordChars('_','_');
	}
    
	public TokenType nextToken() throws IOException {
		streamTokenizer.nextToken();
		sval = streamTokenizer.sval;
		nval = (int)streamTokenizer.nval;
		return ttype = nextTokenType();
	}

	protected TokenType nextTokenType() throws IOException {
		switch(streamTokenizer.ttype) {
		case StreamTokenizer.TT_EOF:
			return EOF;
		case StreamTokenizer.TT_NUMBER:
			return NUM ;
		case StreamTokenizer.TT_WORD:
			TokenType t=keywords.get(sval);
			return t!=null ? t : ID; 
		case '+': return PLUS;
		case '*': return TIMES;
		case ':': return COLON;
		case ';': return SEMICOLON;
		case ',': return COMMA;
		case '(': return OROUND;
		case ')': return CROUND;
		case '=': return EQUAL;
		}
		return UNKNOWN;
	}
    
	public static void main(String[] args) throws IOException {
		Reader r=new BufferedReader(new InputStreamReader(System.in));
		Scanner t=new Scanner(r);
		for(;;) {
			t.nextToken();
			if (t.ttype==EOF)
				break;
			System.out.println(t.ttype);
		}
	}
}
